@@ -1,44 +1,47 @@
-# $Id: geogMask.R, v1.1.6 2015/03/01 12:00:00 hsbadr EPS JHU           #
-#----------------------------------------------------------------------#
-# This function is a part of HiClimR R package.                        #
-#----------------------------------------------------------------------#
-#  HISTORY:                                                            #
-#----------------------------------------------------------------------#
-#  Version  |  Date      |  Comment   |  Author       |  Email         #
-#----------------------------------------------------------------------#
-#           |  May 1992  |  Original  |  F. Murtagh   |                #
-#           |  Dec 1996  |  Modified  |  Ross Ihaka   |                #
-#           |  Apr 1998  |  Modified  |  F. Leisch    |                #
-#           |  Jun 2000  |  Modified  |  F. Leisch    |                #
-#----------------------------------------------------------------------#
-#  1.00     |  03/07/14  |  Modified  |  Hamada Badr  |  badr@jhu.edu  #
-#  1.01     |  03/08/14  |  Updated   |  Hamada Badr  |  badr@jhu.edu  #
-#  1.02     |  03/09/14  |  Updated   |  Hamada Badr  |  badr@jhu.edu  #
-#  1.03     |  03/12/14  |  Updated   |  Hamada Badr  |  badr@jhu.edu  #
-#  1.04     |  03/14/14  |  Updated   |  Hamada Badr  |  badr@jhu.edu  #
-#  1.05     |  03/18/14  |  Updated   |  Hamada Badr  |  badr@jhu.edu  #
-#  1.06     |  03/25/14  |  Updated   |  Hamada Badr  |  badr@jhu.edu  #
-#  1.07     |  03/30/14  |  Updated   |  Hamada Badr  |  badr@jhu.edu  #
-#  1.08     |  05/06/14  |  Updated   |  Hamada Badr  |  badr@jhu.edu  #
-#----------------------------------------------------------------------#
-#  1.0.9    |  05/07/14  |  CRAN      |  Hamada Badr  |  badr@jhu.edu  #
-#  1.1.0    |  05/15/14  |  Updated   |  Hamada Badr  |  badr@jhu.edu  #
-#  1.1.1    |  07/14/14  |  Updated   |  Hamada Badr  |  badr@jhu.edu  #
-#  1.1.2    |  07/26/14  |  Updated   |  Hamada Badr  |  badr@jhu.edu  #
-#  1.1.3    |  08/28/14  |  Updated   |  Hamada Badr  |  badr@jhu.edu  #
-#  1.1.4    |  09/01/14  |  Updated   |  Hamada Badr  |  badr@jhu.edu  #
-#  1.1.5    |  11/12/14  |  Updated   |  Hamada Badr  |  badr@jhu.edu  #
-#----------------------------------------------------------------------#
-#  1.1.6    |  01/03/15  |  GitHub    |  Hamada Badr  |  badr@jhu.edu  #
-#----------------------------------------------------------------------#
-# COPYRIGHT(C) 2013-2015 Earth and Planetary Sciences (EPS), JHU.      #
-#----------------------------------------------------------------------#
-# Function: Geographic mask from longitude and latitute                #
-#----------------------------------------------------------------------#
+# $Id: geogMask.R, v1.2.0 2015/03/27 12:00:00 hsbadr EPS JHU              #
+#-------------------------------------------------------------------------#
+# This function is a part of HiClimR R package.                           #
+#-------------------------------------------------------------------------#
+#  HISTORY:                                                               #
+#-------------------------------------------------------------------------#
+#  Version  |  Date      |  Comment   |  Author          |  Email         #
+#-------------------------------------------------------------------------#
+#           |  May 1992  |  Original  |  F. Murtagh      |                #
+#           |  Dec 1996  |  Modified  |  Ross Ihaka      |                #
+#           |  Apr 1998  |  Modified  |  F. Leisch       |                #
+#           |  Jun 2000  |  Modified  |  F. Leisch       |                #
+#-------------------------------------------------------------------------#
+#   1.0.0   |  03/07/14  |  HiClimR   |  Hamada S. Badr  |  badr@jhu.edu  #
+#   1.0.1   |  03/08/14  |  Updated   |  Hamada S. Badr  |  badr@jhu.edu  #
+#   1.0.2   |  03/09/14  |  Updated   |  Hamada S. Badr  |  badr@jhu.edu  #
+#   1.0.3   |  03/12/14  |  Updated   |  Hamada S. Badr  |  badr@jhu.edu  #
+#   1.0.4   |  03/14/14  |  Updated   |  Hamada S. Badr  |  badr@jhu.edu  #
+#   1.0.5   |  03/18/14  |  Updated   |  Hamada S. Badr  |  badr@jhu.edu  #
+#   1.0.6   |  03/25/14  |  Updated   |  Hamada S. Badr  |  badr@jhu.edu  #
+#-------------------------------------------------------------------------#
+#   1.0.7   |  03/30/14  |  Hybrid    |  Hamada S. Badr  |  badr@jhu.edu  #
+#   1.0.8   |  05/06/14  |  Updated   |  Hamada S. Badr  |  badr@jhu.edu  #
+#-------------------------------------------------------------------------#
+#   1.0.9   |  05/07/14  |  CRAN      |  Hamada S. Badr  |  badr@jhu.edu  #
+#   1.1.0   |  05/15/14  |  Updated   |  Hamada S. Badr  |  badr@jhu.edu  #
+#   1.1.1   |  07/14/14  |  Updated   |  Hamada S. Badr  |  badr@jhu.edu  #
+#   1.1.2   |  07/26/14  |  Updated   |  Hamada S. Badr  |  badr@jhu.edu  #
+#   1.1.3   |  08/28/14  |  Updated   |  Hamada S. Badr  |  badr@jhu.edu  #
+#   1.1.4   |  09/01/14  |  Updated   |  Hamada S. Badr  |  badr@jhu.edu  #
+#   1.1.5   |  11/12/14  |  Updated   |  Hamada S. Badr  |  badr@jhu.edu  #
+#-------------------------------------------------------------------------#
+#   1.1.6   |  03/01/15  |  GitHub    |  Hamada S. Badr  |  badr@jhu.edu  #
+#-------------------------------------------------------------------------#
+#   1.2.0   |  03/27/15  |  MVC       |  Hamada S. Badr  |  badr@jhu.edu  #
+#-------------------------------------------------------------------------#
+# COPYRIGHT(C) 2013-2015 Earth and Planetary Sciences (EPS), JHU.         #
+#-------------------------------------------------------------------------#
+# Function: Geographic mask from longitude and latitute                   #
+#-------------------------------------------------------------------------#
 
 # Function: Geographic mask for an area from longitude and latitute
 geogMask <- function(continent = NULL, region = NULL, country = NULL, lon = NULL, 
-    lat = NULL, InDispute = TRUE, plot = FALSE, colPalette = NULL) {
+    lat = NULL, InDispute = TRUE, verbose = TRUE, plot = FALSE, colPalette = NULL) {
     
     # Get World mask from LazyData
     wMask <- get("WorldMask", envir = .GlobalEnv)
@@ -109,7 +112,8 @@ geogMask <- function(continent = NULL, region = NULL, country = NULL, lon = NULL
     }
     
     if (plot) {
-        if (length(lon) == length(unique(lon)) * length(unique(lat))) {
+        if (verbose) write("Generating geographic mask map...", "")
+        if (as.numeric(length(lon)) == as.numeric(length(unique(lon)) * length(unique(lat)))) {
             Regions <- rep(-1, length(lon))
             Regions[gMask] <- NA
             RegionsMap <- matrix(Regions, nrow = length(unique(lon)), byrow = TRUE)
@@ -125,9 +129,10 @@ geogMask <- function(continent = NULL, region = NULL, country = NULL, lon = NULL
             Latitude <- unique(lat)
             image(Longitude, Latitude, RegionsMap, col = colPalette(2))
         } else {
-            write("plot is avaiable only for gridded data", "")
+            write("---> plot is avaiable only for gridded data", "")
         }
     }
     
+    #gc()
     return(gMask)
 }
